==> libcamera-docs-0.1.0-1.1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/variables_2.js <==
var searchData=
[
  ['c0_0',['c0',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinearConstants.html#ab6ec14eab6b6f6b2f336c546f15ab09e',1,'libcamera::ipa::CameraSensorHelper::AnalogueGainLinearConstants']]],
  ['c1_1',['c1',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinearConstants.html#a31a1237a307dde2ec1c5417c008a12cb',1,'libcamera::ipa::CameraSensorHelper::AnalogueGainLinearConstants']]],
  ['cameraadded_2',['cameraAdded',['../classlibcamera_1_1CameraManager.html#a6c2071f9f9228348b5943c0de7234b21',1,'libcamera::CameraManager']]],
  ['cameraremoved_3',['cameraRemoved',['../classlibcamera_1_1CameraManager.html#a710506c6dde09353c702537cf6106b90',1,'libcamera::CameraManager']]],
  ['cfapattern_4',['cfaPattern',['../structlibcamera_1_1IPACameraSensorInfo.html#a13b8b008b1ca47bbcfb5a54601d6ba89',1,'libcamera::IPACameraSensorInfo']]],
  ['cmd_5',['cmd',['../structlibcamera_1_1IPCMessage_1_1Header.html#abfcfb21b9e61c03af82aea84a8723384',1,'libcamera::IPCMessage::Header']]],
  ['colorcorrectionaberrationmode_6',['ColorCorrectionAberrationMode',['../namespacelibcamera_1_1controls_1_1draft.html#a9433ed2e15c237e454e0b9a0aeedee86',1,'libcamera::controls::draft']]],
  ['colorcorrectionaberrationmodevalues_7',['ColorCorrectionAberrationModeValues',['../namespacelibcamera_1_1controls_1_1draft.html#ada97ec169207f8d5603cb7735f1c6705',1,'libcamera::controls::draft']]],
  ['colorfilterarrangement_8',['ColorFilterArrangement',['../namespacelibcamera_1_1properties_1_1draft.html#aa78da631754b5448008dc32964e53e42',1,'libcamera::properties::draft']]],
  ['colorfilterarrangementvalues_9',['ColorFilterArrangementValues',['../namespacelibcamera_1_1properties_1_1draft.html#a52b22cee6164770663407a08f526240e',1,'libcamera::properties::draft']]],
  ['colorspace_10',['colorSpace',['../structlibcamera_1_1StreamConfiguration.html#a99ead3d97d71da92b6560164e860bb34',1,'libcamera::StreamConfiguration::colorSpace'],['../classlibcamera_1_1V4L2DeviceFormat.html#ad587e1cdee8d6075e7c57294125c0219',1,'libcamera::V4L2DeviceFormat::colorSpace'],['../structlibcamera_1_1V4L2SubdeviceFormat.html#a034b0bb3ccc3b30318c3e5f764f2dfa0',1,'libcamera::V4L2SubdeviceFormat::colorSpace']]],
  ['colourcorrectionmatrix_11',['ColourCorrectionMatrix',['../namespacelibcamera_1_1controls.html#ae41d67783e62f20de02a621417d222aa',1,'libcamera::controls']]],
  ['colourencoding_12',['colourEncoding',['../classlibcamera_1_1PixelFormatInfo.html#a4876401366f11a4c02e6b5e1e3669219',1,'libcamera::PixelFormatInfo']]],
  ['colourgains_13',['ColourGains',['../namespacelibcamera_1_1controls.html#ace9f01b925044ae563a6e08e930ebff7',1,'libcamera::controls']]],
  ['colourtemperature_14',['ColourTemperature',['../namespacelibcamera_1_1controls.html#a8754d2609a3a04ce5ec5880d5d4e8e5d',1,'libcamera::controls']]],
  ['config_5f_15',['config_',['../classlibcamera_1_1CameraConfiguration.html#a183135f8db18b681b44520ed687e4410',1,'libcamera::CameraConfiguration']]],
  ['configuration_16',['configuration',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html#a25085e66bcc15ff4cc3e1aa20e288f95',1,'libcamera::ipa::ipu3::IPAContext']]],
  ['configuration_5f_17',['configuration_',['../classlibcamera_1_1Stream.html#ac4322d978e351a67154464bdf1a23840',1,'libcamera::Stream']]],
  ['configurationfile_18',['configurationFile',['../structlibcamera_1_1IPASettings.html#a92de2e5154b0af540c7e8211c212bd5b',1,'libcamera::IPASettings']]],
  ['connected_5f_19',['connected_',['../classlibcamera_1_1IPCPipe.html#acb942c141d05a35f8756067abd32f2ce',1,'libcamera::IPCPipe']]],
  ['contrast_20',['Contrast',['../namespacelibcamera_1_1controls.html#a76f39d8c7048f1cea3af63bd2839d6b4',1,'libcamera::controls']]],
  ['controlinfo_5f_21',['controlInfo_',['../classlibcamera_1_1Camera_1_1Private.html#ab4e183eb4dabe929d1b2bbbb519b969f',1,'libcamera::Camera::Private']]],
  ['controls_22',['controls',['../namespacelibcamera_1_1controls.html#a886fdba02620052f01c89a6686d17537',1,'libcamera::controls']]],
  ['cookie_23',['cookie',['../structlibcamera_1_1IPCMessage_1_1Header.html#af889b0b96f974cd4d94d80c54a0a5d68',1,'libcamera::IPCMessage::Header']]],
  ['count_24',['count',['../structlibcamera_1_1ipa__control__value__entry.html#a120d1970c4c874858ec58adf7233fae5',1,'libcamera::ipa_control_value_entry']]],
  ['counted_25',['counted',['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#a08e26e3e97f49187b8a9259210aeceeb',1,'libcamera::ipa::ipu3::algorithms::Accumulator']]]
];

==> libcamera-docs-0.2.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/api-html/search/variables_2.js <==
var searchData=
[
  ['c0_0',['c0',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinearConstants.html#ab6ec14eab6b6f6b2f336c546f15ab09e',1,'libcamera::ipa::CameraSensorHelper::AnalogueGainLinearConstants']]],
  ['c1_1',['c1',['../structlibcamera_1_1ipa_1_1CameraSensorHelper_1_1AnalogueGainLinearConstants.html#a31a1237a307dde2ec1c5417c008a12cb',1,'libcamera::ipa::CameraSensorHelper::AnalogueGainLinearConstants']]],
  ['cameraadded_2',['cameraAdded',['../classlibcamera_1_1CameraManager.html#a6c2071f9f9228348b5943c0de7234b21',1,'libcamera::CameraManager']]],
  ['cameraremoved_3',['cameraRemoved',['../classlibcamera_1_1CameraManager.html#a710506c6dde09353c702537cf6106b90',1,'libcamera::CameraManager']]],
  ['cfapattern_4',['cfaPattern',['../structlibcamera_1_1IPACameraSensorInfo.html#a13b8b008b1ca47bbcfb5a54601d6ba89',1,'libcamera::IPACameraSensorInfo']]],
  ['cmd_5',['cmd',['../structlibcamera_1_1IPCMessage_1_1Header.html#abfcfb21b9e61c03af82aea84a8723384',1,'libcamera::IPCMessage::Header']]],
  ['colorcorrectionaberrationmode_6',['ColorCorrectionAberrationMode',['../namespacelibcamera_1_1controls_1_1draft.html#a9433ed2e15c237e454e0b9a0aeedee86',1,'libcamera::controls::draft']]],
  ['colorcorrectionaberrationmodevalues_7',['ColorCorrectionAberrationModeValues',['../namespacelibcamera_1_1controls_1_1draft.html#ada97ec169207f8d5603cb7735f1c6705',1,'libcamera::controls::draft']]],
  ['colorfilterarrangement_8',['ColorFilterArrangement',['../namespacelibcamera_1_1properties_1_1draft.html#aa78da631754b5448008dc32964e53e42',1,'libcamera::properties::draft']]],
  ['colorfilterarrangementvalues_9',['ColorFilterArrangementValues',['../namespacelibcamera_1_1properties_1_1draft.html#a52b22cee6164770663407a08f526240e',1,'libcamera::properties::draft']]],
  ['colorspace_10',['colorSpace',['../structlibcamera_1_1V4L2SubdeviceFormat.html#a034b0bb3ccc3b30318c3e5f764f2dfa0',1,'libcamera::V4L2SubdeviceFormat::colorSpace'],['../classlibcamera_1_1V4L2DeviceFormat.html#ad587e1cdee8d6075e7c57294125c0219',1,'libcamera::V4L2DeviceFormat::colorSpace'],['../structlibcamera_1_1StreamConfiguration.html#a99ead3d97d71da92b6560164e860bb34',1,'libcamera::StreamConfiguration::colorSpace']]],
  ['colourcorrectionmatrix_11',['ColourCorrectionMatrix',['../namespacelibcamera_1_1controls.html#ae41d67783e62f20de02a621417d222aa',1,'libcamera::controls']]],
  ['colourencoding_12',['colourEncoding',['../classlibcamera_1_1PixelFormatInfo.html#a4876401366f11a4c02e6b5e1e3669219',1,'libcamera::PixelFormatInfo']]],
  ['colourgains_13',['ColourGains',['../namespacelibcamera_1_1controls.html#ace9f01b925044ae563a6e08e930ebff7',1,'libcamera::controls']]],
  ['colourtemperature_14',['ColourTemperature',['../namespacelibcamera_1_1controls.html#a8754d2609a3a04ce5ec5880d5d4e8e5d',1,'libcamera::controls']]],
  ['config_5f_15',['config_',['../classlibcamera_1_1CameraConfiguration.html#a183135f8db18b681b44520ed687e4410',1,'libcamera::CameraConfiguration']]],
  ['configuration_16',['configuration',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAContext.html#a25085e66bcc15ff4cc3e1aa20e288f95',1,'libcamera::ipa::ipu3::IPAContext']]],
  ['configuration_5f_17',['configuration_',['../classlibcamera_1_1Stream.html#ac4322d978e351a67154464bdf1a23840',1,'libcamera::Stream']]],
  ['configurationfile_18',['configurationFile',['../structlibcamera_1_1IPASettings.html#a92de2e5154b0af540c7e8211c212bd5b',1,'libcamera::IPASettings']]],
  ['connected_5f_19',['connected_',['../classlibcamera_1_1IPCPipe.html#acb942c141d05a35f8756067abd32f2ce',1,'libcamera::IPCPipe']]],
  ['contrast_20',['Contrast',['../namespacelibcamera_1_1controls.html#a76f39d8c7048f1cea3af63bd2839d6b4',1,'libcamera::controls']]],
  ['controlinfo_5f_21',['controlInfo_',['../classlibcamera_1_1Camera_1_1Private.html#ab4e183eb4dabe929d1b2bbbb519b969f',1,'libcamera::Camera::Private']]],
  ['controls_22',['controls',['../namespacelibcamera_1_1controls.html#a886fdba02620052f01c89a6686d17537',1,'libcamera::controls']]],
  ['cookie_23',['cookie',['../structlibcamera_1_1IPCMessage_1_1Header.html#af889b0b96f974cd4d94d80c54a0a5d68',1,'libcamera::IPCMessage::Header']]],
  ['count_24',['count',['../structlibcamera_1_1ipa__control__value__entry.html#a120d1970c4c874858ec58adf7233fae5',1,'libcamera::ipa_control_value_entry']]],
  ['counted_25',['counted',['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#a08e26e3e97f49187b8a9259210aeceeb',1,'libcamera::ipa::ipu3::algorithms::Accumulator']]]
];
